From 16f3e16a4da781e56064402e0cf48c5a5bae1c78 Mon Sep 17 00:00:00 2001
From: "godzilla80@gmx.net" <>
Date: Wed, 15 Apr 2009 21:23:22 +0000
Subject: Fixed Issue #117 - TValidationSummary: new display mode "HeaderOnly"
that only render value of HeaderText property
---
framework/Web/Javascripts/source/prado/validator/validation3.js | 4 +++-
1 file changed, 3 insertions(+), 1 deletion(-)
(limited to 'framework/Web/Javascripts/source')
diff --git a/framework/Web/Javascripts/source/prado/validator/validation3.js b/framework/Web/Javascripts/source/prado/validator/validation3.js
index 9db1e7d6..850536ab 100644
--- a/framework/Web/Javascripts/source/prado/validator/validation3.js
+++ b/framework/Web/Javascripts/source/prado/validator/validation3.js
@@ -675,7 +675,7 @@ Prado.WebUI.TValidationSummary.prototype =
/**
* Return the format parameters for the summary.
* @function {object} ?
* @param {string} type - Format type: "List", "SingleParagraph" or "BulletList" (default)
* @return Object with format parameters:
* @... {string} header - Text for header
* @... {string} first - Text to prepend before message list
@@ -691,6 +691,8 @@ Prado.WebUI.TValidationSummary.prototype =
return { header : "
", first : "", pre : "", post : "
", last : ""};
case "SingleParagraph":
return { header : " ", first : "", pre : "", post : " ", last : "
"};
+ case "HeaderOnly":
+ return { header : "", first : ""};
case "BulletList":
default:
return { header : "", first : "
@@ -675,7 +675,7 @@ Prado.WebUI.TValidationSummary.prototype =
* Return the format parameters for the summary.
* @function {object} ?
- * @param {string} type - Format type: "List", "SingleParagraph" or "BulletList" (default)
+ * @param {string} type - Format type: "List", "SingleParagraph", "HeaderOnly" or "BulletList" (default)
* @return Object with format parameters:
* @... {string} header - Text for header